﻿namespace UrsComPortExtensions
{
   /// <summary>
   /// Stellt die Daten für die Ereignisse <see cref="ComPortSelector.DeviceAdded">UsbDeviceAdded</see> 
   /// und <see cref="ComPortSelector.DeviceRemoved">UsbDeviceRemoved</see> bereit.
   /// </summary>
   public class DeviceChangedEventArgs
   {
      /// <summary>
      /// Die eindeutige ID des Geräts (z.B.'USB\VID_067B&amp;PID_2303\6&amp;F9BED0F&amp;0&amp;4'). 
      /// </summary>
      /// <remarks>Die ID ist im gleichen Format wie sie von der WMI geliefert wird und kann direkt mit 
      /// <see cref="ComPortDescriptor.DeviceID"/> verglichen werden.</remarks>
      public readonly String DeviceID;

      /// <summary>
      /// Wenn es sich um einen ComPort handelt: Name des Ports (z.B. CCOM6). Ansonsten null.
      /// </summary>
      public readonly String? ComPortName;

      /// <summary>
      /// Initialsiert eine neue Instanz der <see cref="DeviceChangedEventArgs"/>-Klasse.
      /// </summary>
      /// <param name="DeviceID">Die eindeutige ID des Geräts.</param>
      /// <param name="ComPortName">Der Name des Ports (z.B. "COM6").</param>
      public DeviceChangedEventArgs(String DeviceID, String? ComPortName)
      {
         this.DeviceID = DeviceID;
         this.ComPortName = ComPortName;
      }
   }
}